@@ -76,8 +76,9 @@ sub invoke {
     die unless GetOptions ($cmd, _opt_map($cmd, $cmd->options));
     my @args = $cmd->parse_arg(@ARGV);
     $cmd->lock (@args);
-    my $ret = $cmd->run (@args);
+    my $ret = eval { $cmd->run (@args) };
     $xd->unlock () if $xd;
+    die $@ if $@;
     return $ret;
 }
 
@@ -111,8 +112,14 @@ sub usage {
     $buf =~ s/^AUTHORS.*//sm;
     $buf =~ s/^DESCRIPTION.*//sm unless $detail;
     foreach my $line (split(/\n/, $buf, -1)) {
-	if ($line =~ /^(\s*)(.+)(\s*)$/) {
-	    print $1, loc($2), $3, "\n";
+	if ($line =~ /^(\s*)(.+?: )( *)(.+?)(\s*)$/) {
+	    my $spaces = $3;
+	    my $loc = $1 . loc($2 . $4) . $5;
+	    $loc =~ s/: /: $spaces/ if $spaces;
+	    print $loc, "\n";
+	}
+	elsif ($line =~ /^(\s*)(.+?)(\s*)$/) {
+	    print $1||'', loc($2), $3||'', "\n";
 	}
 	else {
 	    print "\n";
@@ -138,7 +145,7 @@ sub arg_condensed {
     $self->usage if $#arg < 0;
     my ($report, $copath, @targets )= $self->{xd}->condense (@arg);
 
-    my ($repospath, $path, $cinfo, $repos) = main::find_repos_from_co ($copath, 1);
+    my ($repospath, $path, $cinfo, $repos) = $self->{xd}->find_repos_from_co ($copath, 1);
     return { repos => $repos,
 	     repospath => $repospath,
 	     copath => $copath,
@@ -152,7 +159,7 @@ sub arg_co_maybe {
     my ($self, $arg) = @_;
 
     my ($repospath, $path, $copath, $cinfo, $repos) =
-	main::find_repos_from_co_maybe ($arg, 1);
+	$self->{xd}->find_repos_from_co_maybe ($arg, 1);
     return { repos => $repos,
 	     repospath => $repospath,
 	     depotpath => $cinfo->{depotpath} || $arg,
@@ -164,7 +171,7 @@ sub arg_co_maybe {
 sub arg_copath {
     my ($self, $arg) = @_;
 
-    my ($repospath, $path, $cinfo, $repos) = main::find_repos_from_co ($arg, 1);
+    my ($repospath, $path, $cinfo, $repos) = $self->{xd}->find_repos_from_co ($arg, 1);
     return { repos => $repos,
 	     repospath => $repospath,
 	     copath => Cwd::abs_path ($arg),
@@ -177,7 +184,7 @@ sub arg_copath {
 sub arg_depotpath {
     my ($self, $arg) = @_;
 
-    my ($repospath, $path, $repos) = main::find_repos ($arg, 1);
+    my ($repospath, $path, $repos) = $self->{xd}->find_repos ($arg, 1);
 
     return { repos => $repos,
 	     repospath => $repospath,
@@ -189,7 +196,7 @@ sub arg_depotpath {
 sub arg_depotname {
     my ($self, $arg) = @_;
 
-    return main::find_depotname ($arg, 1);
+    return $self->{xd}->find_depotname ($arg, 1);
 }
 
 sub arg_path {
