@@ -1,6 +1,6 @@
 package SVK::Command::Commit;
 use strict;
-our $VERSION = '0.11';
+our $VERSION = '0.13';
 use base qw( SVK::Command );
 use SVK::XD;
 use SVK::I18N;
@@ -166,27 +166,6 @@ sub get_editor {
 	  );
 
     return ($editor, %cb, mirror => $m, callback => \$callback);
-
-=begin comment
-
-    if ($self->{sign} && !$self->{check_only}) {
-	my $digest = IO::String->new;
-	$cb_closed = sub {
-	    print $digest join(' ', 'MD5', $_[1], $_[0])."\n";
-	};
-	my $old_cb_merged = $cb_merged;
-	$cb_merged = sub { my ($editor, $baton, $pool) = @_;
-			   my $sig =_sign_gpg ('/tmp/svk-sign',
-					       ${$digest->string_ref});
-			   $editor->change_dir_prop
-			       ($baton, 'svk:signature', $sig);
-			   &{$old_cb_merged} (@_) };
-    }
-
-=end comment
-
-=cut
-
 }
 
 
@@ -326,6 +305,8 @@ sub run {
 
 1;
 
+__DATA__
+
 =head1 NAME
 
 SVK::Command::Commit - Commit changes to depot
